# Temml Math Test

A variety of Temml-rendered math elements using the `hurmet-tex` pattern.

## Accents

F→ `\vec{F}` | a~ `\tilde{a}` | θ^ `\hat{\theta}`
a˙ `\dot{a}` | A B `\overline{AB}` | A B⏞ `\overbrace{AB}`

## Fractions and Roots

Inline fraction: a b and square root: x 2+y 2.

Cube root: 8 3

## Display Math

E=m c 2

## Operators

∑ `\sum` | ∫ `\int` | ∏ `\prod` | ∮ `\oint`

## Environments

(a b c d) | `\begin{pmatrix}` `a & b \\` `c & d` `\end{pmatrix}`

## Greek and Symbols

Greek letters: α, β, γ, Ω

Relation: a≤b, not equal: x≠y